from rfhotjup import rfhotjup

def get_stellar_system_param():
    return rfhotjup.get_planet_param()

def get_star_param():
    return rfhotjup.get_star_param()

def get_stellar_wind_param():
    return rfhotjup.get_stellar_wind_param()

def get_planet_param():
    return rfhotjup.get_planet_param()
